Package: maidr
Type: Package
Title: Multimodal Access and Interactive Data Representation
Version: 0.3.0
Authors@R: c(
    person("JooYoung", "Seo", email = "jseo1005@illinois.edu", role = c("aut", "cph")),
    person("Niranjan", "Kalaiselvan", email = "nk46@illinois.edu", role = c("aut", "cre"))
    )
URL: https://github.com/xability/r-maidr, https://r.maidr.ai/
BugReports: https://github.com/xability/r-maidr/issues
Description: Provides accessible, interactive visualizations through the 'MAIDR'
    (Multimodal Access and Interactive Data Representation) system. Converts
    'ggplot2' and Base R plots into accessible HTML/SVG formats with keyboard
    navigation, screen reader support, and 'sonification' capabilities. Supports
    bar charts (simple, grouped, stacked), histograms, line plots, scatter plots,
    box plots, violin plots, heat maps, density/smooth curves, faceted plots,
    multi-panel layouts (including patchwork), and multi-layered plot combinations. Enables
    data exploration for users with visual impairments through multiple sensory
    modalities. For more details see the 'MAIDR' project
    <https://maidr.ai/>.
License: GPL (>= 3)
Encoding: UTF-8
Depends: R (>= 3.5.0)
Imports: base64enc, curl, ggplot2, ggplotify, grid, gridSVG, htmltools,
        htmlwidgets, jsonlite, shiny, xml2, rlang, R6
Suggests: testthat (>= 3.0.0), lintr, styler, goodpractice, cyclocomp,
        knitr, rmarkdown, quarto, patchwork
Config/testthat/edition: 3
RoxygenNote: 7.3.2
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-04-01 02:58:55 UTC; niranjank
Author: JooYoung Seo [aut, cph],
  Niranjan Kalaiselvan [aut, cre]
Maintainer: Niranjan Kalaiselvan <nk46@illinois.edu>
Repository: CRAN
Date/Publication: 2026-04-01 05:30:02 UTC
Built: R 4.6.0; ; 2026-04-29 04:40:20 UTC; unix
