# Generated by roxygen2: do not edit by hand

export(abline)
export(arrows)
export(assocplot)
export(axis)
export(barplot)
export(boxplot)
export(chartSeries)
export(contour)
export(coplot)
export(curve)
export(dotchart)
export(grid)
export(heatmap)
export(hist)
export(image)
export(layout)
export(legend)
export(lines)
export(maidr_get_fallback)
export(maidr_off)
export(maidr_on)
export(maidr_output)
export(maidr_set_fallback)
export(matplot)
export(mosaicplot)
export(mtext)
export(pairs)
export(par)
export(pie)
export(plot)
export(points)
export(polygon)
export(rect)
export(render_maidr)
export(run_example)
export(save_html)
export(segments)
export(show)
export(split.screen)
export(stem)
export(stripchart)
export(symbols)
export(text)
export(title)
importFrom(R6,R6Class)
importFrom(ggplotify,as.grob)
importFrom(grid,grid.draw)
importFrom(grid,grid.newpage)
importFrom(gridSVG,grid.export)
importFrom(htmlwidgets,createWidget)
importFrom(htmlwidgets,shinyRenderWidget)
importFrom(htmlwidgets,shinyWidgetOutput)
importFrom(htmlwidgets,sizingPolicy)
importFrom(shiny,installExprFunction)
importFrom(stats,setNames)
importFrom(utils,getS3method)
