---
name: Bug report
about: Create a report to help us improve
title: "fix(): address an issue where "
labels: bug
assignees: ''
---

# Bug Report

## Description
<!-- Please provide a clear and concise description of the bug. -->

## Steps to Reproduce

1. Step 1
2. Step 2
3. Step 3

## Actual Behavior
<!-- Please describe what actually happened. -->

## Expected Behavior
<!-- Please describe what you expected to happen. -->

## Screenshots
<!-- If applicable, add screenshots to help explain the problem. -->
<!-- You can take a gif animation screenshot very easily without any additional installation by using this browser-based tool: -->
<!-- https://gifcap.dev -->

## Environment
- Operating System: [e.g. Windows 10]
- Browser: [e.g. Chrome, Firefox]
- Version: [e.g. 1.0.0]

## Additional Information
<!-- Add any other relevant information about the problem here. -->
